==> bbwa-0.0.4.tar.gz: bbwa-0.0.4/left.php <==
<?php
//
// BBWA
// left.php
// ɽ
// Teppei KAKU <teppei@sat.co.jp>
//
?>


<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.0 Transitional//EN">
<html>
<head>
<title>BBWA</title>
<meta http-equiv="Content-Type" content="text/html; charset=euc-jp">
<link rel="stylesheet" type="text/css" href="default.css">
</head>
<body class="left">
<table border="0" align="center">


<?php
include("variables.php");

// ڡ岼Υɽ
function printIcons($current, $pages) {
  print("<tr><td nowrap align=\"center\" class=\"button\">\n");
  if ($current > 1) {
    $prev = $current - 1;

    echo <<<EOD
<a href="left.php?page=1&order=${_GET['order']}"
  target="LEFT"><img src="Icons/icon_first.png" align="absmiddle"
  alt="ƬΥڡ" border="0"></a>
<a href="left.php?page=${prev}&order=${_GET['order']}"
  target="LEFT"><img src="Icons/icon_left.png" align="absmiddle"
  alt="Υڡ" border="0"></a>
EOD;

  } else {
    print("<img src=\"Icons/icon_first_d.png\" align=\"absmiddle\" " .
      "border=\"0\">\n");
    print("<img src=\"Icons/icon_left_d.png\" align=\"absmiddle\" " .
      "border=\"0\">");
  }
  if ($current < $pages) {
    $next = $current + 1;

    echo <<<EOD
<a href="left.php?page=${next}&order=${_GET['order']}"
  target="LEFT"><img src="Icons/icon_right.png" align="absmiddle"
  alt="Υڡ" border="0"></a>
<a href="left.php?page=${pages}&order=${_GET['order']}"
  target="LEFT"><img src="Icons/icon_last.png" align="absmiddle"
  alt="ǸΥڡ" border="0"></a>
EOD;

  } else {
    print("<img src=\"Icons/icon_right_d.png\" align=\"absmiddle\" " .
      "border=\"0\">\n");
    print("<img src=\"Icons/icon_last_d.png\" align=\"absmiddle\" " .
      "border=\"0\">");
  }
  print("</td></tr>");
}

// 
$tempArray = array();
$dirHandle = opendir($dirName);
switch ($_GET['order']) {
  case 1:
    while ($fileList = readdir($dirHandle)) { 
      if (eregi("\.jpg|\.png|\.gif$", $fileList)) {
        array_push($tempArray, $fileList);
      }
    }
    rsort($tempArray);
    $fileArray = $tempArray;
    break;
  case 2:
    while ($fileList = readdir($dirHandle)) { 
      if (eregi("\.jpg|\.png|\.gif$", $fileList)) {
        array_push($tempArray, $fileList);
      }
    }
    sort($tempArray);
    $fileArray = $tempArray;
    break;
  default:
    while ($fileList = readdir($dirHandle)) { 
      if (eregi("\.jpg|\.png|\.gif$", $fileList)) {
        $tempArray[$fileList] =
          filemtime("${dirName}Messages/${fileList}_mes.txt");
      }
    }
    arsort($tempArray);
    $fileArray = array_keys($tempArray);
}
closedir($dirHandle);

// ڡ׻
$pages = (int) ((count($fileArray) - 1) / $perPage + 1);
if ($_GET['page'] == "end") {
  $current = $pages;
} else {
  $current = min($_GET['page'], $pages);
}

$imgStart = ($current - 1) * $perPage;
$imgEnd = min(($imgStart + $perPage), count($fileArray));

if (count($fileArray) > 0) {
  print("<tr><td align=\"center\">" .
    "<strong>${current}/${pages}</strong> ڡ</td></tr>");
  printIcons($current, $pages);

  for ($i = $imgStart; $i < $imgEnd; $i++) {
    print("<tr><td align=\"center\" class=\"photoframe\">");

    // ɤ߹
    $filePtr = fopen("${dirName}Messages/${fileArray[$i]}_mes.txt", "r");
    $pizza = fgets($filePtr, 1024);
    $pizza = htmlspecialchars($pizza);
    $piece = explode("|||", $pizza);
    fclose($filePtr);

    // ͥɽ
    print("<a href=\"right.php?img=${fileArray[$i]}&order=${_GET['order']}\"" .
       "target=\"RIGHT\">");
    if (eregi("\.gif$", $fileArray[$i])) {
      print("<img src=\"${picUrl}${fileArray[$i]}\"" .
        "border=\"0\" width=\"${piece[0]}\" height=\"${piece[1]}\"" .
        "alt=\"${piece[2]}\n${piece[3]}\n${piece[5]}\">");
    } else {
      print("<img src=\"${picUrl}Thumbnails/${fileArray[$i]}_thumb.jpg\"" .
        "border=\"0\" alt=\"${piece[2]}\n${piece[3]}\n${piece[5]}\">");
    }
    print("</a>");
    print("</td></tr>\n");
  }

  print("<a name=\"bt\">");
  printIcons($current, $pages);
  print("</a>");
} else {
  print("<tr><td align=\"center\">NO IMAGE!</td></tr>");
}
?>


</table>
</body>
</html>

==> bbwa-0.0.5.tar.gz: bbwa-0.0.5/left.php <==
<?php
//
// BBWA
// left.php
// ɽ
// Teppei KAKU <teppei@sat.co.jp>
//

include("variables.php");
?>


<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.0 Transitional//EN">
<html>
<head>
<title>BBWA</title>
<meta http-equiv="Content-Type" content="text/html; charset=euc-jp">


<?php

echo <<<EOD
<link rel="stylesheet" type="text/css" href="Themes/${theme}.css">
<script language="JavaScript">
<!--
function scrollEnd() {
  order = ${_GET['order']};
  page = "${_GET['page']}";
  if (order == 2 && page == "END") {
    window.scrollTo(0, 10000);
  }
}
//-->
</script>
EOD;

?>


</head>
<body class="left" onLoad="scrollEnd()">
<table border="0" align="center">


<?php
// ڡ岼Υɽ
function printIcons($current, $pages) {
  print("<tr><td nowrap align=\"center\" class=\"button\">\n");
  if ($current > 1) {
    $prev = $current - 1;

    echo <<<EOD
<a href="left.php?page=1&order=${_GET['order']}"
  target="LEFT"><img src="Icons/icon_first.png" align="absmiddle"
  alt="ƬΥڡ" border="0"></a>
<a href="left.php?page=${prev}&order=${_GET['order']}"
  target="LEFT"><img src="Icons/icon_left.png" align="absmiddle"
  alt="Υڡ" border="0"></a>
EOD;

  } else {
    print("<img src=\"Icons/icon_first_d.png\" align=\"absmiddle\" " .
      "border=\"0\">\n");
    print("<img src=\"Icons/icon_left_d.png\" align=\"absmiddle\" " .
      "border=\"0\">");
  }
  if ($current < $pages) {
    $next = $current + 1;

    echo <<<EOD
<a href="left.php?page=${next}&order=${_GET['order']}"
  target="LEFT"><img src="Icons/icon_right.png" align="absmiddle"
  alt="Υڡ" border="0"></a>
<a href="left.php?page=${pages}&order=${_GET['order']}"
  target="LEFT"><img src="Icons/icon_last.png" align="absmiddle"
  alt="ǸΥڡ" border="0"></a>
EOD;

  } else {
    print("<img src=\"Icons/icon_right_d.png\" align=\"absmiddle\" " .
      "border=\"0\">\n");
    print("<img src=\"Icons/icon_last_d.png\" align=\"absmiddle\" " .
      "border=\"0\">");
  }
  print("</td></tr>");
}

// ǥåɤ߹
$tempArray = array();
$filePtr = fopen("${dirName}INDEX", "r");
while ($pizza = fgets($filePtr, 1024)) {
  $piece = explode("|||", $pizza);
  $tempArray[$piece[0]] = $piece[1];
}
switch ($_GET['order']) {
  case 1:
    krsort($tempArray);
    break;
  case 2:
    ksort($tempArray);
    break;
  default:
    arsort($tempArray);
}
$fileArray = array_keys($tempArray);
fclose($filePtr);

// ڡ׻
$pages = (int) ((count($fileArray) - 1) / $perPage + 1);
if ($_GET['page'] == "END") {
  $current = $pages;
} else {
  $current = min($_GET['page'], $pages);
}

$imgStart = ($current - 1) * $perPage;
$imgEnd = min(($imgStart + $perPage), count($fileArray));

if (count($fileArray) > 0) {
  print("<tr><td align=\"center\">" .
    "<strong>${current}/${pages}</strong> ڡ</td></tr>");
  printIcons($current, $pages);

  for ($i = $imgStart; $i < $imgEnd; $i++) {
    print("<tr><td align=\"center\" class=\"photoframe\">");

    // ɤ߹
    $filePtr = fopen("${dirName}Messages/${fileArray[$i]}_mes.txt", "r");
    $pizza = fgets($filePtr, 1024);
    $pizza = htmlspecialchars($pizza);
    $piece = explode("|||", $pizza);
    fclose($filePtr);

    // ͥɽ
    print("<a href=\"right.php?img=${fileArray[$i]}\"" .
       "target=\"RIGHT\">");
    if (eregi("\.gif$", $fileArray[$i])) {
      print("<img src=\"${picUrl}${fileArray[$i]}\"" .
        "border=\"0\" width=\"${piece[0]}\" height=\"${piece[1]}\"" .
        "alt=\"${piece[2]}\n${piece[3]}\n${piece[5]}\">");
    } else {
      print("<img src=\"${picUrl}Thumbnails/${fileArray[$i]}_thumb.jpg\"" .
        "border=\"0\" alt=\"${piece[2]}\n${piece[3]}\n${piece[5]}\">");
    }
    print("</a>");
    print("</td></tr>\n");
  }

  print("<a name=\"bt\">");
  printIcons($current, $pages);
  print("</a>");
} else {
  print("<tr><td align=\"center\">NO IMAGE!</td></tr>");
}
?>


</table>
</body>
</html>
